==> server-api-3.0.3-sources.jar: com/xebialabs/deployit/core/api/dto/TaskInfo.java <==
package com.xebialabs.deployit.core.api.dto;

import java.util.Calendar;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name = "task-info")
public class TaskInfo extends AbstractDTO {

    private String id;
    
    private String label;

	private String state;

	private Calendar startDate;

	private Calendar completionDate;

	private int nrOfSteps;

	private int currentStepNr;
	
	private String user;

    @XmlElement(name = "id")
    public String getId() {
        return id;
    }

    public void setId(final String id) {
        this.id = id;
    }
    
    @XmlElement(name = "label")
    public String getLabel() {
    	return label;
    }

	public void setLabel(String label) {
    	this.label = label;
    }

	@XmlElement(name = "state")
	public String getState() {
		return state;
	}

	public void setState(String state) {
		this.state = state;
	}

	@XmlElement(name = "start-date")
	public Calendar getStartDate() {
		return startDate;
	}

	public void setStartDate(Calendar startDate) {
		this.startDate = startDate;
	}

	@XmlElement(name = "completion-date")
	public Calendar getCompletionDate() {
		return completionDate;
	}

	public void setCompletionDate(Calendar completionDate) {
		this.completionDate = completionDate;
	}

	@XmlElement(name = "nr-of-steps")
	public int getNrOfSteps() {
		return nrOfSteps;
	}

	public void setNrOfSteps(int nrOfSteps) {
		this.nrOfSteps = nrOfSteps;
	}

	@XmlElement(name = "current-step-nr")
	public int getCurrentStepNr() {
		return currentStepNr;
	}

	public void setCurrentStepNr(int currentStepId) {
		this.currentStepNr = currentStepId;
	}

	@XmlElement(name = "user")
	public String getUser() {
    	return user;
    }

	public void setUser(String user) {
    	this.user = user;
    }

}

==> server-api-3.7.3-sources.jar: com/xebialabs/deployit/core/api/dto/TaskInfo.java <==
package com.xebialabs.deployit.core.api.dto;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.Calendar;

@XmlRootElement(name = "task-info")
public class TaskInfo extends AbstractDTO {

    private String id;
    
    private String label;

	private String state;

	private Calendar startDate;

	private Calendar completionDate;

	private int nrOfSteps;

	private int currentStepNr;
	
	private String user;

    private String application;

    private String version;

    private String environment;

    private int failureCount;

    @XmlElement(name = "id")
    public String getId() {
        return id;
    }

    public void setId(final String id) {
        this.id = id;
    }
    
    @XmlElement(name = "label")
    public String getLabel() {
    	return label;
    }

	public void setLabel(String label) {
    	this.label = label;
    }

	@XmlElement(name = "state")
	public String getState() {
		return state;
	}

	public void setState(String state) {
		this.state = state;
	}

	@XmlElement(name = "start-date")
	public Calendar getStartDate() {
		return startDate;
	}

	public void setStartDate(Calendar startDate) {
		this.startDate = startDate;
	}

	@XmlElement(name = "completion-date")
	public Calendar getCompletionDate() {
		return completionDate;
	}

	public void setCompletionDate(Calendar completionDate) {
		this.completionDate = completionDate;
	}

	@XmlElement(name = "nr-of-steps")
	public int getNrOfSteps() {
		return nrOfSteps;
	}

	public void setNrOfSteps(int nrOfSteps) {
		this.nrOfSteps = nrOfSteps;
	}

	@XmlElement(name = "current-step-nr")
	public int getCurrentStepNr() {
		return currentStepNr;
	}

	public void setCurrentStepNr(int currentStepId) {
		this.currentStepNr = currentStepId;
	}

	@XmlElement(name = "user")
	public String getUser() {
    	return user;
    }

	public void setUser(String user) {
    	this.user = user;
    }

    @XmlElement(name = "application")
    public String getApplication() {
        return application;
    }

    public void setApplication(String application) {
        this.application = application;
    }

    @XmlElement(name = "version")
    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    @XmlElement(name = "environment")
    public String getEnvironment() {
        return environment;
    }

    public void setEnvironment(String environment) {
        this.environment = environment;
    }

    @XmlElement(name = "failure-count")
    public int getFailureCount() {
        return failureCount;
    }

    public void setFailureCount(int failureCount) {
        this.failureCount = failureCount;
    }
}
